/*
 * Copyright 2008-2009 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package javarequirementstracer;

import static java.lang.annotation.ElementType.TYPE;

import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Marker annotation to mark exported (public/proteced) types that need to exported but are 
 * not required by any requirement, so they can be excluded from reports.
 * See {@link Requirements}. 
 * <p/>
 * NB.1. Prefer reducing the scope of a type/method to private or package-private over this annotation. 
 * <br/>NB.2. This annotation is not and should not be inheritable.
 * 
 * @author Ronald Koster
 */
@Target({TYPE})
@Retention(RetentionPolicy.RUNTIME) // NB. Idem as at Requirements. 
@SuppressTraceabilityWarnings
public @interface SuppressTraceabilityWarnings {
}
